<?php
/**
 * Customizer Partial Functions
 *
 * @package Theme_Palace
 * @since Business Center Pro 2.0.0
 */

/**
 * Render the site title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 *
 * @return void
 */
function business_center_pro_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 *
 * @return void
 */
function business_center_pro_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Render the service title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_service_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['service_title'] );
}

/**
 * Render the service sub title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_service_sub_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['service_sub_title'] );
}

/**
 * Render the features read more text for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_feature_view_more_text() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['custom_feature_view_more_text'] );
}

/**
 * Render the testimonial title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_testimonial_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['testimonial_title'] );
}

/**
 * Render the testimonial sub title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_testimonial_sub_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['testimonial_sub_title'] );
}

/**
 * Render the portfolio title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_portfolio_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['portfolio_title'] );
}

/**
 * Render the portfolio sub title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_portfolio_sub_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['portfolio_sub_title'] );
}

/**
 * Render the call to action title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_call_to_action_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['call_to_action_title'] );
}

/**
 * Render the call to action sub title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_call_to_action_sub_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['call_to_action_sub_title'] );
}

/**
 * Render the call to action content for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_call_to_action_content() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['call_to_action_content'] );
}

/**
 * Render the call to action btn text for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_call_to_action_btn_txt() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['call_to_action_btn_txt'] );
}

/**
 * Render the pricing title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_pricing_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['pricing_title'] );
}

/**
 * Render the pricing sub title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_pricing_sub_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['pricing_sub_title'] );
}


/**
 * Render the front page blog title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_front_page_blog_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['front_page_blog_title'] );
}

/**
 * Render the front page blog sub title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_front_page_blog_sub_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['front_page_blog_sub_title'] );
}

/**
 * Render the team title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_team_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['team_title'] );
}

/**
 * Render the team sub title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_team_sub_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['team_sub_title'] );
}

/**
 * Render the team read more btn text for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_team_read_more_btn_txt() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['team_read_more_btn_txt'] );
}

/**
 * Render the client title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_client_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['client_title'] );
}

/**
 * Render the client title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_client_sub_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['client_sub_title'] );
}

/**
 * Render the contact title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_contact_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['contact_title'] );
}

/**
 * Render the contact sub title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_contact_sub_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['contact_sub_title'] );
}

/**
 * Render the skill title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_skill_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['skill_title'] );
}

/**
 * Render the skill sub title for the selective refresh partial.
 *
 * @since Business Center Pro 2.0.0
 * @return string
 */
function business_center_pro_partial_skill_sub_title() {
	$options = business_center_pro_get_theme_options();
	return esc_html( $options['skill_sub_title'] );
}