<?php
/**
 * Team options
 *
 * @package Theme Palace
 * @subpackage Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */


// Add team section
$wp_customize->add_section( 'business_center_pro_team_section', array(
	'title'       => esc_html__( 'Team Options','business-center-pro' ),
	'description' => esc_html__( 'The recommended image size for team image is 330 by 520. ', 'business-center-pro' ),
	'panel'       => 'business_center_pro_sections_panel',
) );


/**
 * Team Options
 */
// Enable team.
$wp_customize->add_setting( 'business_center_pro_theme_options[enable_team]', array(
	'default'           => $options['enable_team'],
	'sanitize_callback' => 'business_center_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'business_center_pro_theme_options[enable_team]', array(
	'label'             => esc_html__( 'Enable Team Section?', 'business-center-pro' ),
	'section'           => 'business_center_pro_team_section',
	'type'				=> 'checkbox'
) );

// Team title.
$wp_customize->add_setting( 'business_center_pro_theme_options[team_title]', array(
	'default'           => $options['team_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'business_center_pro_theme_options[team_title]', array(
	'active_callback'	=> 'business_center_pro_is_team_enable',
	'label'             => esc_html__( 'Title:', 'business-center-pro' ),
	'section'           => 'business_center_pro_team_section',
	'type'				=> 'text'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'business_center_pro_theme_options[team_title]', array(
		'selector'            => '#team .entry-header .entry-title',
		'render_callback'     => 'business_center_pro_partial_team_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Team sub-title.
$wp_customize->add_setting( 'business_center_pro_theme_options[team_sub_title]', array(
	'default'           => $options['team_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'business_center_pro_theme_options[team_sub_title]', array(
	'active_callback'	=> 'business_center_pro_is_team_enable',
	'label'             => esc_html__( 'Sub Title:', 'business-center-pro' ),
	'section'           => 'business_center_pro_team_section',
	'type'				=> 'text'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'business_center_pro_theme_options[team_sub_title]', array(
		'selector'            => '#team .entry-header .subtitle',
		'render_callback'     => 'business_center_pro_partial_team_sub_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

/**
 * Team content type options.
 */
$wp_customize->add_setting( 'business_center_pro_theme_options[team_content_type]', array(
	'default'           => $options['team_content_type'],
	'sanitize_callback' => 'business_center_pro_sanitize_select',
) );

$wp_customize->add_control( 'business_center_pro_theme_options[team_content_type]', array(
	'active_callback'	=> 'business_center_pro_is_team_enable',
	'label'             => esc_html__( 'Content Type', 'business-center-pro' ),
	'section'           => 'business_center_pro_team_section',
	'choices'			=> business_center_pro_team_content_type_options(),
	'type'				=> 'select'
) );

// Number of team.
$wp_customize->add_setting( 'business_center_pro_theme_options[number_of_team]', array(
	'default'           => $options['number_of_team'],
	'sanitize_callback' => 'business_center_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'business_center_pro_theme_options[number_of_team]', array(
	'active_callback'	=> 'business_center_pro_is_team_demo_disable',
	'label'             => esc_html__( 'Number of team? ( Max: 4 )', 'business-center-pro' ),
	'description'       => esc_html__( 'Note: Please refresh after changing the value to see the changes.', 'business-center-pro' ),
	'section'           => 'business_center_pro_team_section',
	'input_attrs'		=> array( 'min' => 1, 'max' => 4 ),
	'type'				=> 'number'
) );

/**
 * Category Content Type Options
 */
// Catgegory Options
$wp_customize->add_setting( 'business_center_pro_theme_options[team_category]', array(
	'sanitize_callback' => 'business_center_pro_sanitize_tax_checkbox'
) );

$wp_customize->add_control( new Business_Center_Pro_Customize_Control_Checkbox_Multiple( $wp_customize, 'business_center_pro_theme_options[team_category]', array(
	'active_callback' => 'business_center_pro_is_team_content_type_category_enable',
	'label'           => esc_html__( 'Select Category', 'business-center-pro' ),
	'section'         => 'business_center_pro_team_section',
	'type'            => 'checkbox-multiple',
	'taxonomy'		  => 'category',
) ) );

// Horizontal Line
$wp_customize->add_setting( 'business_center_pro_theme_options[team_content_content_type_hr' . $i . ']', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Business_Center_Pro_Customize_Horizontal_Line( $wp_customize, 'business_center_pro_theme_options[team_content_content_type_hr' . $i . ']',
	array(
		'active_callback' => 'business_center_pro_is_team_demo_disable',
		'section'         => 'business_center_pro_team_section',
		'type'			  => 'hr',
) ) );

for ( $i=1; $i <= $options['number_of_team']; $i++ ) { 
	/**
	 * Custom Content Type Options
	 */
	// Team name text options
	$wp_customize->add_setting( 'business_center_pro_theme_options[custom_team_name_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'business_center_pro_theme_options[custom_team_name_'.$i.']', array(
		'active_callback' => 'business_center_pro_is_team_content_type_custom_enable',
		'label'           => esc_html__( 'Name ', 'business-center-pro' ) . $i,
		'section'         => 'business_center_pro_team_section',
		'type'            => 'text',
	) );

	// Team content options
	$wp_customize->add_setting( 'business_center_pro_theme_options[custom_team_content_'.$i.']', array(
		'sanitize_callback' => 'esc_textarea'
	) );

	$wp_customize->add_control( 'business_center_pro_theme_options[custom_team_content_'.$i.']', array(
		'active_callback' => 'business_center_pro_is_team_content_type_custom_enable',
		'label'           => esc_html__( 'Content ', 'business-center-pro' ) . $i,
		'section'         => 'business_center_pro_team_section',
		'type'            => 'textarea',
	) );

	// Team position text options
	$wp_customize->add_setting( 'business_center_pro_theme_options[custom_team_position_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'business_center_pro_theme_options[custom_team_position_'.$i.']', array(
		'active_callback' => 'business_center_pro_is_team_demo_disable',
		'label'           => esc_html__( 'Position ', 'business-center-pro' ) . $i,
		'description'     =>  ( 1 !== $i ? '' : esc_html__( 'Input the team position here as per the posts.', 'business-center-pro' ) ),
		'section'         => 'business_center_pro_team_section',
		'type'            => 'text',
	) );

	// Team url options
	$wp_customize->add_setting( 'business_center_pro_theme_options[custom_team_url_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw'
	) );

	$wp_customize->add_control( 'business_center_pro_theme_options[custom_team_url_'.$i.']', array(
		'active_callback' => 'business_center_pro_is_team_content_type_custom_enable',
		'label'           => esc_html__( 'URL ', 'business-center-pro' ) . $i,
		'section'         => 'business_center_pro_team_section',
		'type'            => 'url',
	) );

	// Team image options
	$wp_customize->add_setting( 'business_center_pro_theme_options[custom_team_image_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'business_center_pro_theme_options[custom_team_image_'.$i.']', array(
		'active_callback' => 'business_center_pro_is_team_content_type_custom_enable',
		'label'           => esc_html__( 'Image ', 'business-center-pro' ) . $i,
		'description'     => esc_html__( 'The recommeded size for the image is 400px by 225px. ', 'business-center-pro' ) . $i,
		'section'         => 'business_center_pro_team_section',
	) ) );
	
	for ( $j=1; $j <= 3; $j++ ) { 
		// Team social Link options
		$wp_customize->add_setting( 'business_center_pro_theme_options[custom_team_social_url_'.$i.'-'.$j.']', array(
			'sanitize_callback' => 'esc_url_raw'
		) );

		$wp_customize->add_control( 'business_center_pro_theme_options[custom_team_social_url_'.$i.'-'.$j.']', array(
			'active_callback' => 'business_center_pro_is_team_demo_disable',
			'label'           => esc_html__( 'Social Link ', 'business-center-pro' ) . $j,
			'section'         => 'business_center_pro_team_section',
			'type'            => 'url',
		) );
	}

	// Horizontal Line
	$wp_customize->add_setting( 'business_center_pro_theme_options[team_content_type_hr' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Business_Center_Pro_Customize_Horizontal_Line( $wp_customize, 'business_center_pro_theme_options[team_content_type_hr' . $i . ']',
		array(
			'active_callback' => 'business_center_pro_is_team_demo_disable',
			'section'         => 'business_center_pro_team_section',
			'type'			  => 'hr',
	) ) );
}

// Read more button text.
$wp_customize->add_setting( 'business_center_pro_theme_options[team_read_more_btn_txt]', array(
	'default'           => $options['team_read_more_btn_txt'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'business_center_pro_theme_options[team_read_more_btn_txt]', array(
	'active_callback'	=> 'business_center_pro_is_team_enable',
	'label'             => esc_html__( 'Button Text:', 'business-center-pro' ),
	'section'           => 'business_center_pro_team_section',
	'type'				=> 'text'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'business_center_pro_theme_options[team_read_more_btn_txt]', array(
		'selector'            => '#team .btn-transparent',
		'render_callback'     => 'business_center_pro_partial_team_read_more_btn_txt',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Read more button URL.
$wp_customize->add_setting( 'business_center_pro_theme_options[team_read_more_btn_txt_url]', array(
	'default'           => $options['team_read_more_btn_txt_url'],
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'business_center_pro_theme_options[team_read_more_btn_txt_url]', array(
	'active_callback'	=> 'business_center_pro_is_team_enable',
	'label'             => esc_html__( 'Button URL:', 'business-center-pro' ),
	'section'           => 'business_center_pro_team_section',
	'type'				=> 'url'
) );