<?php 
/**
 * Client section
 *
 * This is the template for the content of client section
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */

if ( ! function_exists( 'business_center_pro_add_client_section' ) ) :
  /**
   * Add client section
   *
   *@since Business Center Pro 2.0.0
   */
  function business_center_pro_add_client_section() {
    // Check if client is enabled
    $enable_client = apply_filters( 'business_center_pro_section_status', true, 'enable_client' );

    if ( true !== $enable_client ) {
      return false;
    }

    // Get client section details
    $section_details = array();

    $section_details = apply_filters( 'business_center_pro_filter_client_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render client section now.
    business_center_pro_render_client_section( $section_details );
  }
endif;
add_action( 'business_center_pro_core_modules', 'business_center_pro_add_client_section', 30 );


if ( ! function_exists( 'business_center_pro_get_client_section_details' ) ) :
  /**
   * Client section details.
   *
   * @since Business Center Pro 2.0.0
   * @param array $input Client section details.
   */
  function business_center_pro_get_client_section_details( $input ) {
    $options = business_center_pro_get_theme_options();

    // Client type
    $client_content_type  = $options['client_content_type'];

    $content = array();
    switch ( $client_content_type ) {
      	case 'demo':
	        for ( $i=1; $i<=6; $i++ ) {
            $content[ $i ]['image']         = get_template_directory_uri() . '/assets/uploads/company-logo-0'.$i.'.png';
            $content[ $i ]['link']         = '#';
	        }
      	break;

        case 'custom':
          for ( $i=1; $i<=$options['number_of_client']; $i++ ) {
            if ( isset( $options['custom_client_image_'.$i] ) ) {
              $content[ $i ]['image']         = $options['custom_client_image_'.$i];
            }
            if ( isset( $options['custom_client_link_'.$i] ) ) {
              $content[ $i ]['link']         = $options['custom_client_link_'.$i];
            }
          }
        break;

      	default:
      	break;
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Client section content details.
add_filter( 'business_center_pro_filter_client_section_details', 'business_center_pro_get_client_section_details' );


if ( ! function_exists( 'business_center_pro_render_client_section' ) ) :
  /**
   * Start client section
   *
   * @return string Client content
   * @since Business Center Pro 2.0.0
   *
   */
   function business_center_pro_render_client_section( $content_details = array() ) {
        $options = business_center_pro_get_theme_options();

        if ( empty( $content_details ) ) {
          return;
        } 
        ?>
        <section id="client-logos" class="page-section no-padding-bottom">
          <div class="container">
            <header class="entry-header">
              <div class="separate"></div>
              <h2 class="entry-title"><?php echo esc_html( $options['client_title'] ); ?></h2>  
              <p class="subtitle"><?php echo esc_html( $options['client_sub_title'] ); ?></p>
            </header><!-- .entry-header -->
          </div><!-- .container -->

          <div class="entry-content three-columns">
          <?php foreach ($content_details as $content ) { 
            if ( ! empty( $content['image'] ) ) { ?>
            <div class="column-wrapper">
              <a href="<?php echo ( ! empty( $content['link'] ) ) ? esc_url( $content['link'] ) : ''; ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt=""></a>
            </div><!--.column-wrapper-->
            <?php }
          } ?>
          </div><!--.entry-content-->
        </section><!-- #client-logos --> 
<?php 
    }
endif;