<?php 
/**
 * Contact section
 *
 * This is the template for the content of contact section
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */

if ( ! function_exists( 'business_center_pro_add_contact_section' ) ) :
  /**
   * Add contact section
   *
   *@since Business Center Pro 2.0.0
   */
  function business_center_pro_add_contact_section() {
    // Check if contact is enabled
    $enable_contact = apply_filters( 'business_center_pro_section_status', true, 'enable_contact' );

    if ( true !== $enable_contact ) {
      return false;
    }

    // Render contact section now.
    business_center_pro_render_contact_section();
  }
endif;
add_action( 'business_center_pro_site_content_end', 'business_center_pro_add_contact_section', 10 );


if ( ! function_exists( 'business_center_pro_render_contact_section' ) ) :
  /**
   * Start contact section
   *
   * @return string Contact content
   * @since Business Center Pro 2.0.0
   *
   */
   function business_center_pro_render_contact_section() {
        $options = business_center_pro_get_theme_options();

       
        ?>
        <section id="contact-form" class="page-section no-padding-bottom">
          <header class="entry-header">
            <div class="separate"></div>
              <?php if ( ! empty( $options['contact_title'] ) ) { ?>
                <h2 class="entry-title"><?php echo esc_html( $options['contact_title'] ); ?></h2>  
              <?php } 
              if ( ! empty( $options['contact_sub_title'] ) ) { ?>
                <p class="subtitle"><?php echo esc_html( $options['contact_sub_title'] ); ?></p>
              <?php } ?>
          </header><!-- .entry-header -->
          <div class="two-columns clear">

            <?php 
            // Render background image
            if ( ! empty( $options['custom_contact_image'] ) ) { 
              $bg_image = $options['custom_contact_image']; ?>
              <div class="column-wrapper">
                <div class="fixed-bg" style="background-image:url( '<?php echo esc_url( $bg_image ); ?>' )"></div>
              </div><!-- .column-wrapper -->
            <?php } ?>

            <div class="column-wrapper">       
              <div class="entry-content">
                <?php if ( ! empty( $options['custom_contact_form_shortcode'] ) ) { ?>
                  <div role="form" class="wpcf7" id="wpcf7-f21-p2-o1" lang="en-US" dir="ltr">
                      <?php echo do_shortcode( wp_kses_post( $options['custom_contact_form_shortcode'] ) ); ?>
                  </div><!-- .wpcf7 -->
                <?php } ?>
              </div><!-- .entry-content -->
            </div><!-- .column-wrapper -->
          </div><!-- .twp-columns -->
          <div id="contact-details" class="call-to-action clear">
            <div class="container">
              <ul>
                <?php for ( $i=1; $i <= 3; $i++ ) { 
                  if ( isset( $options['custom_contact_info_icon_'.$i] ) && isset( $options['custom_contact_info_value_'.$i] ) ) { ?>
                    <li><i class="fa <?php echo esc_attr( $options['custom_contact_info_icon_'.$i] );?>"></i><a href=""><?php echo esc_html( $options['custom_contact_info_value_'.$i] );?></a></li>
                  <?php } 
                  } ?>
              </ul>
            </div><!-- .container -->
          </div><!-- #contact-details -->
          <?php if ( ! empty( $options['custom_contact_map_shortcode'] ) ) { ?>
            <div id="map"><?php echo do_shortcode( wp_kses_post( $options['custom_contact_map_shortcode'] ) ); ?></div><!-- #map -->
          <?php } ?>
        </section><!-- #contact-form -->
<?php 
    }
endif;