<?php 
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */

if ( ! function_exists( 'business_center_pro_add_service_section' ) ) :
  /**
   * Add service section
   *
   *@since Business Center Pro 2.0.0
   */
  function business_center_pro_add_service_section() {
    // Check if service is enabled
    $enable_service = apply_filters( 'business_center_pro_section_status', true, 'enable_service' );

    if ( true !== $enable_service ) {
      return false;
    }

    // Get service section details
    $section_details = array();

    $section_details = apply_filters( 'business_center_pro_filter_service_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render service section now.
    business_center_pro_render_service_section( $section_details );
  }
endif;
add_action( 'business_center_pro_core_modules', 'business_center_pro_add_service_section', 30 );


if ( ! function_exists( 'business_center_pro_get_service_section_details' ) ) :
  /**
   * Service section details.
   *
   * @since Business Center Pro 2.0.0
   * @param array $input Service section details.
   */
  function business_center_pro_get_service_section_details( $input ) {
    $options = business_center_pro_get_theme_options();

    // Service type
    $service_content_type  = $options['service_content_type'];

    $content = array();
    switch ( $service_content_type ) {
      	case 'demo':
          $icon_arr = array( 'fa-diamond', 'fa-paper-plane', 'fa-institution' );
          $title_arr = array( esc_html__( 'Several design options', 'business-center-pro' ), esc_html__( 'Clean & modern design', 'business-center-pro' ), esc_html__( 'Build your website', 'business-center-pro' ) );

	        for ( $i=0; $i<=2; $i++ ) {
            $content[ $i ]['icon']      = $icon_arr[ $i ];
            $content[ $i ]['title']     = $title_arr[ $i ];
            $content[ $i ]['url']       = '#';
            $content[ $i ]['sub_title'] = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod.', 'business-center-pro' );
	        }
      	break;

        case 'custom':
          for ( $i=1; $i<=$options['number_of_services']; $i++ ) {
            if ( isset( $options['custom_service_icon_'.$i] ) ) {
              $content[ $i ]['icon']      = $options['custom_service_icon_'.$i];
            }
            if ( isset( $options['custom_service_title_'.$i] ) ) {
              $content[ $i ]['title']     = $options['custom_service_title_'.$i];
            }
            if ( isset( $options['custom_service_sub_title_'.$i] ) ) {
              $content[ $i ]['sub_title'] = $options['custom_service_sub_title_'.$i];
            }
            if ( isset( $options['custom_service_link_'.$i] ) ) {
              $content[ $i ]['url']       = $options['custom_service_link_'.$i];
            }
          }
        break;

      	case 'service':
          $ids = array();
          for ( $i = 1; $i <= $options['number_of_services']; $i++ ) {
              $id = null;
              if ( isset( $options[ 'service_post_type_content_type_'.$i ] ) ) {
                  $id = $options[ 'service_post_type_content_type_'.$i ];
              }
              if ( ! empty( $id ) ) {
                  $ids[] = absint( $id );
              }
          }

          // Bail if no valid pages are selected.
          if ( empty( $ids ) ) {
              return $input;
          }

	        $args = array(
	            'no_found_rows'  => true,
	            'orderby'        => 'post__in',
	            'post_type'      => 'tp-service',
	            'post__in'       => $ids,
	        );
      	break;

      	case 'category':
	        $cat_id = array();
	        if ( !empty( $options['service_category'] ) ) {
	            $cat_id = $options['service_category'];
	        }

	        // Bail if no valid pages are selected.
	        if ( empty( $cat_id ) ) {
	            return $input;
	        }else{
	            $cat_id =  (array)$cat_id;
	        }
	        $args = array(
              'no_found_rows'  => true,
              'category__in'   => $cat_id,
              'post_type'      => 'post',
              'posts_per_page' => absint( $options['number_of_services'] ),
              'orderby'        => 'ASC',
	        );
      	break;

      	default:
      	break;
    }

    if ( 'demo' != $service_content_type && 'custom' != $service_content_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {
            $post_id = $post->ID;

            $content[ $i ]['title']       = get_the_title( $post_id );
            $content[ $i ]['sub_title']   = business_center_pro_trim_content( 20, $post );
            $content[ $i ]['url']         = get_the_permalink( $post_id );

            if ( 'service' == $service_content_type ) {
                $content[ $i ]['icon']  = get_post_meta( $post_id, 'tp-service-icon', true );
            } else {
                if ( isset( $options['custom_service_icon_'.$i] ) ) {
                    $content[ $i ]['icon']      = $options['custom_service_icon_'.$i];
                }
            }
            $i++;
          }
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Service section content details.
add_filter( 'business_center_pro_filter_service_section_details', 'business_center_pro_get_service_section_details' );


if ( ! function_exists( 'business_center_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string Service content
   * @since Business Center Pro 2.0.0
   *
   */
   function business_center_pro_render_service_section( $content_details = array() ) {
        $options = business_center_pro_get_theme_options();

        if ( empty( $content_details ) ) {
          return;
        } 
        ?>
        <section id="services" class="page-section bg-white">
          <div class="container">
            <header class="entry-header">
              <div class="separate"></div>
              <h2 class="entry-title"><?php echo esc_html( $options['service_title'] ); ?></h2>  
              <p class="subtitle"><?php echo esc_html( $options['service_sub_title'] ); ?></p>
            </header><!-- .entry-header -->

            <div class="entry-content three-columns">
              <div class="row">
              <?php foreach ( $content_details as $content ) { 
                ?>
                <div class="column-wrapper">
                    <div class="title">
                      <!-- <span>01</span> -->
                      <?php if ( ! empty( $content['icon'] ) ) { ?>
                        <span><i class="fa <?php echo esc_attr( $content['icon'] );?>"></i></span>
                      <?php } ?>
                      <?php if ( ! empty( $content['title'] ) ) { ?>
                        <a href="<?php echo esc_url( $content['url'] ); ?>"><h3><?php echo esc_html( $content['title'] ); ?></h3></a> 
                      <?php } ?>
                      <?php if ( ! empty( $content['sub_title'] ) ) { ?>
                        <p><?php echo esc_html( $content['sub_title'] ); ?></p>
                      <?php } ?>
                    </div><!-- .title -->
                </div><!-- .column-wrapper -->
              <?php  }  ?>
              </div><!-- .row -->
            </div><!-- .entry-content -->
            </div><!-- .container -->
        </section><!-- #services -->
<?php 
    }
endif;