<?php 
/**
 * Skill section
 *
 * This is the template for the content of skill section
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */

if ( ! function_exists( 'business_center_pro_add_skill_section' ) ) :
  /**
   * Add skill section
   *
   *@since Business Center Pro 2.0.0
   */
  function business_center_pro_add_skill_section() {
    // Check if skill is enabled
    $enable_skill = apply_filters( 'business_center_pro_section_status', true, 'enable_skill' );

    if ( true !== $enable_skill ) {
      return false;
    }

    // Get skill section details
    $section_details = array();

    $section_details = apply_filters( 'business_center_pro_filter_skill_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Localize script
    wp_localize_script( 'business-center-pro-custom-pie-chart', 'skill_content', $section_details );

    // Render skill section now.
    business_center_pro_render_skill_section( $section_details );
  }
endif;
add_action( 'business_center_pro_core_modules', 'business_center_pro_add_skill_section', 30 );


if ( ! function_exists( 'business_center_pro_get_skill_section_details' ) ) :
  /**
   * Skill section details.
   *
   * @since Business Center Pro 2.0.0
   * @param array $input Skill section details.
   */
  function business_center_pro_get_skill_section_details( $input ) {
    $options = business_center_pro_get_theme_options();

    // Skill type
    $skill_content_type  = $options['skill_content_type'];

    $content = array();
    switch ( $skill_content_type ) {
      	case 'demo':
	        for ( $i=0; $i<=2; $i++ ) {
            $label_arr = array( esc_html__( 'Development', 'business-center-pro' ), esc_html__( 'PROGRAMMING', 'business-center-pro' ), esc_html__( 'DESIGN', 'business-center-pro' ) );
            $color_arr = array( "#FFDAB9", "#E6E6FA", "#E0FFFF", "#E6E6FA" );
            $value_arr = array( 27, 23, 50 );
            $content[ $i ]['label']         = $label_arr[ $i ];
            $content[ $i ]['value']         = $value_arr[ $i ];
            $content[ $i ]['color']         = $color_arr[ $i ];
	        }
      	break;

        case 'custom':
          for ( $i=0; $i < $options['number_of_skill']; $i++ ) {
            if ( isset( $options['custom_skill_name_'.$i] ) ) {
              $content[ $i ]['label']         = $options['custom_skill_name_'.$i];
            }
            if ( isset( $options['custom_skill_value_'.$i] ) ) {
              $content[ $i ]['value']         = $options['custom_skill_value_'.$i];
            }
            if ( isset( $options['custom_skill_color_'.$i] ) ) {
              $content[ $i ]['color']         = $options['custom_skill_color_'.$i];
            }
          }
        break;

      	default:
      	break;
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Skill section content details.
add_filter( 'business_center_pro_filter_skill_section_details', 'business_center_pro_get_skill_section_details' );


function business_center_pro_enqueue_skill_scripts() {

    $enable_skill = apply_filters( 'business_center_pro_section_status', true, 'enable_skill' );

    // Do not load on other pages
    if ( $enable_skill ) {
      wp_register_script( 'business-center-pro-custom-pie-chart', get_template_directory_uri() . '/assets/js/pie-chart.min.js', array( 'business-center-pro-custom' ), '', true );
      
      wp_enqueue_script( 'business-center-pro-custom-pie-chart' );
    }
}
add_action( 'wp_enqueue_scripts', 'business_center_pro_enqueue_skill_scripts' );


if ( ! function_exists( 'business_center_pro_render_skill_section' ) ) :
  /**
   * Start skill section
   *
   * @return string Skill content
   * @since Business Center Pro 2.0.0
   *
   */
   function business_center_pro_render_skill_section( $content_details = array() ) {
        $options = business_center_pro_get_theme_options();

        if ( empty( $content_details ) ) {
          return;
        } 


        ?>
        <section id="piechart">
          <div class="container">
            <header class="entry-header">
              <div class="separate"></div>
              <?php if ( ! empty( $options['skill_title'] ) ) { ?>
                <h2 class="entry-title"><?php echo esc_html( $options['skill_title'] );?></h2>  
              <?php } ?>
              <?php if ( ! empty( $options['skill_sub_title'] ) ) { ?>
                <p class="subtitle"><?php echo esc_html( $options['skill_sub_title'] ); ?></p>
              <?php } ?>
            </header><!-- .entry-header -->

            <div class="entry-content">
              <canvas id="piechart-canvas" width="900" height="600">
              </canvas>
              <!-- <div id="pie"></div> -->
            </div><!--.entry-content-->
          </div><!-- .container -->
        </section><!-- #piechart -->
<?php 
    }
endif;