<?php
/**
 * Business Center Pro options
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */


/**
 * Section content type
 * @return array content type options
 */
function business_center_pro_content_type() {
  $business_center_pro_content_type = array(
    'demo'  => esc_html__( 'Demo', 'business-center-pro' ),
    'custom'=> esc_html__( 'Custom', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_content_type', $business_center_pro_content_type );

  return $output;
}

/**
 * Site Layout
 * @return array site layout options
 */
function business_center_pro_site_layout() {
  $business_center_pro_site_layout = array(
    'wide'  => esc_html__( 'Wide', 'business-center-pro' ),
    'boxed' => esc_html__( 'Boxed', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_site_layout', $business_center_pro_site_layout );

  return $output;
}

/**
 * Sidebar position
 * @return array Sidbar positions
 */
function business_center_pro_sidebar_position() {
  $business_center_pro_sidebar_position = array(
    'both-sidebar' => esc_html__( 'Both', 'business-center-pro' ),
    'right-sidebar' => esc_html__( 'Right', 'business-center-pro' ),
    'left-sidebar'  => esc_html__( 'Left', 'business-center-pro' ),
    'no-sidebar'    => esc_html__( 'No Sidebar', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_sidebar_position', $business_center_pro_sidebar_position );

  return $output;
}

/**
 * Header image options
 * @return array Header image options
 */
function business_center_pro_header_image() {
  $business_center_pro_header_image = array(
    'enable' => esc_html__( 'Enable( Featured Image )', 'business-center-pro' ),
    'default' => esc_html__( 'Default ( Customizer Header Image )', 'business-center-pro' ),
    'disable'  => esc_html__( 'Disable', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_header_image', $business_center_pro_header_image );

  return $output;
}

/**
 * Pagination
 * @return array site pagination options
 */
function business_center_pro_pagination_options() {
  $business_center_pro_pagination_options = array(
    'numeric'=> esc_html__( 'Numeric', 'business-center-pro' ),
    'default'=> esc_html__( 'Default(Older/Newer)', 'business-center-pro' ),
  );
  if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) {
        $business_center_pro_pagination_options['infinite-click'] = 'Infinite Click';
        $business_center_pro_pagination_options['infinite-scroll'] = 'Infinite Scroll';
    }

  $output = apply_filters( 'business_center_pro_pagination_options', $business_center_pro_pagination_options );

  return $output;
}


/**
 * Slider
 * @return array slider options
 */
function business_center_pro_enable_disable_options() {
  $business_center_pro_enable_disable_options = array(
    'static-frontpage'  => esc_html__( 'Static Frontpage', 'business-center-pro' ),
    'disabled'          => esc_html__( 'Disabled', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_enable_disable_options', $business_center_pro_enable_disable_options );

  return $output;
}


/**
 * Default content type options
 * @return array Content type options
 */
function business_center_pro_default_content_type_options() {
  $business_center_pro_default_content_type_options = array(
    'demo' => esc_html__( 'Demo', 'business-center-pro' ),
    'category' => esc_html__( 'Category', 'business-center-pro' ),
    'page' => esc_html__( 'Pages', 'business-center-pro' ),
    'custom'  => esc_html__( 'Custom', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_default_content_type_options', $business_center_pro_default_content_type_options );

  return $output;
}

/**
 * Returns list of typography
 * @return array font styles
 */
function business_center_pro_typography_options(){

    $choices = array(
      'poppins'   => esc_html__( 'POPPINS AND COURGETTE FONT', 'business-center-pro' ),
      'roboto'    => esc_html__( 'ROBOTO AND MONTSERRAT FONT', 'business-center-pro' ),
      'raleway'   => esc_html__( 'RALEWAY AND POPPINS FONT', 'business-center-pro' ),
      'courgette' => esc_html__( 'COURGETTE AND ROBOTO FONT', 'business-center-pro' ),
      'montserrat'=> esc_html__( 'MONTSERRAT FONT', 'business-center-pro' ),
      'default'   => esc_html__( 'DEFAULT', 'business-center-pro' ),
    );
    $output = apply_filters( 'business_center_pro_typography_options', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

}

/**
 * Slider overlay type options
 * @return array Slider overlay type options
 */
function business_center_pro_overlay_type_options() {
    $business_center_pro_overlay_type_options = array(
    'custom'  => esc_html__( 'Custom', 'business-center-pro' ),
    'white' => esc_html__( 'White', 'business-center-pro' ),
    'gray'  => esc_html__( 'Gray', 'business-center-pro' ),
    'only-caption'  => esc_html__( 'Only on Caption', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_overlay_type_options', $business_center_pro_overlay_type_options );

  return $output;
}

/**
 * Transition effects
 * @return array Transition effects
 */
function business_center_pro_transition_effects_options() {
    $business_center_pro_transition_effects_options = array(
    'fade'                                        => esc_html__( 'Fade', 'business-center-pro' ),
    'cubic-bezier(0.250, 0.250, 0.750, 0.750)'    => esc_html__( 'Linear', 'business-center-pro' ),
    'cubic-bezier(0.250, 0.100, 0.250, 1.000)'    => esc_html__( 'Ease', 'business-center-pro' ),
    'cubic-bezier(0.950, 0.050, 0.795, 0.035)'    => esc_html__( 'Cubic', 'business-center-pro' ),
    'cubic-bezier(0.600, -0.280, 0.735, 0.045)'   => esc_html__( 'Ease In Back', 'business-center-pro' ),
    'cubic-bezier(0.785, 0.135, 0.150, 0.860)'    => esc_html__( 'EaseInOutCirc', 'business-center-pro' ),
    'cubic-bezier(0.680, -0.550, 0.265, 1.550)'   => esc_html__( 'EaseInOutBack', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_transition_effects_options', $business_center_pro_transition_effects_options );

  return $output;
}


/**
 * Service content type options
 * @return array Content type options
 */
function business_center_pro_service_content_type_options() {
  $business_center_pro_service_content_type_options = array(
    'demo'     => esc_html__( 'Demo', 'business-center-pro' ),
    'category' => esc_html__( 'Category', 'business-center-pro' ),
    'custom'   => esc_html__( 'Custom', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_service_content_type_options', $business_center_pro_service_content_type_options );

  return $output;
}

/**
 * Feature content type options
 * @return array Content type options
 */
function business_center_pro_feature_content_type_options() {
  $business_center_pro_feature_content_type_options = array(
    'demo'     => esc_html__( 'Demo', 'business-center-pro' ),
    'category' => esc_html__( 'Category', 'business-center-pro' ),
    'custom'   => esc_html__( 'Custom', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_feature_content_type_options', $business_center_pro_feature_content_type_options );

  return $output;
}

/**
 * Testimonial content type options
 * @return array Content type options
 */
function business_center_pro_testimonial_content_type_options() {
  $business_center_pro_testimonial_content_type_options = array(
    'demo'     => esc_html__( 'Demo', 'business-center-pro' ),
    'category' => esc_html__( 'Category', 'business-center-pro' ),
    'custom'   => esc_html__( 'Custom', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_testimonial_content_type_options', $business_center_pro_testimonial_content_type_options );

  return $output;
}

/**
 * Portfolio content type options
 * @return array Content type options
 */
function business_center_pro_portfolio_content_type_options() {
  $business_center_pro_portfolio_content_type_options = array(
    'demo'     => esc_html__( 'Demo', 'business-center-pro' ),
    'category' => esc_html__( 'Category', 'business-center-pro' ),
    'custom'   => esc_html__( 'Custom', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_portfolio_content_type_options', $business_center_pro_portfolio_content_type_options );

  return $output;
}

/**
 * Call To Action content type options
 * @return array Content type options
 */
function business_center_pro_call_to_action_content_type_options() {
  $business_center_pro_call_to_action_content_type_options = array(
    'demo'   => esc_html__( 'Demo', 'business-center-pro' ),
    'post'   => esc_html__( 'Post', 'business-center-pro' ),
    'custom' => esc_html__( 'Custom', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_call_to_action_content_type_options', $business_center_pro_call_to_action_content_type_options );

  return $output;
}


/**
 * Pricing content type options
 * @return array Content type options
 */
function business_center_pro_pricing_content_type_options() {
  $business_center_pro_pricing_content_type_options = array(
    'demo'   => esc_html__( 'Demo', 'business-center-pro' ),
    'category'   => esc_html__( 'Category', 'business-center-pro' ),
    'custom' => esc_html__( 'Custom', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_pricing_content_type_options', $business_center_pro_pricing_content_type_options );

  return $output;
}

/**
 * Front Page Blog content type options
 * @return array Content type options
 */
function business_center_pro_front_page_blog_content_type_options() {
  $business_center_pro_front_page_blog_content_type_options = array(
    'demo'     => esc_html__( 'Demo', 'business-center-pro' ),
    'category' => esc_html__( 'Category', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_front_page_blog_content_type_options', $business_center_pro_front_page_blog_content_type_options );

  return $output;
}

/**
 * Blog layout options
 * @return array Content type options
 */
function business_center_pro_blog_layout_options() {
  $business_center_pro_blog_layout_options = array(
    'one'   => esc_html__( '1 Column', 'business-center-pro' ),
    'two'   => esc_html__( '2 Columns', 'business-center-pro' ),
    'three' => esc_html__( '3 Columns', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_blog_layout_options', $business_center_pro_blog_layout_options );

  return $output;
}

/**
 * Blog post content type options
 * @return array Content type options
 */
function business_center_pro_blog_content_type_options() {
  $business_center_pro_blog_content_type_options = array(
    'content'   => esc_html__( 'Full Content', 'business-center-pro' ),
    'excerpt'   => esc_html__( 'Excerpt', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_blog_content_type_options', $business_center_pro_blog_content_type_options );

  return $output;
}

/**
 * Team content type options
 * @return array Content type options
 */
function business_center_pro_team_content_type_options() {
  $business_center_pro_team_content_type_options = array(
    'demo'     => esc_html__( 'Demo', 'business-center-pro' ),
    'custom'     => esc_html__( 'Custom', 'business-center-pro' ),
    'category' => esc_html__( 'Category', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_team_content_type_options', $business_center_pro_team_content_type_options );

  return $output;
}

/**
 * Skill content type options
 * @return array Content type options
 */
function business_center_pro_skill_content_type_options() {
  $business_center_pro_skill_content_type_options = array(
    'demo'     => esc_html__( 'Demo', 'business-center-pro' ),
    'custom'     => esc_html__( 'Custom', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_skill_content_type_options', $business_center_pro_skill_content_type_options );

  return $output;
}

/**
 * Client content type options
 * @return array Content type options
 */
function business_center_pro_client_content_type_options() {
  $business_center_pro_client_content_type_options = array(
    'demo'     => esc_html__( 'Demo', 'business-center-pro' ),
    'custom'     => esc_html__( 'Custom', 'business-center-pro' ),
  );

  $output = apply_filters( 'business_center_pro_client_content_type_options', $business_center_pro_client_content_type_options );

  return $output;
}